@@ -5,40 +5,35 @@ from ..const import CMD
 import re
 FALSE_ARR = ['', 'null', 'None', 'false', 'False','0']
 
-def all(region=None, osspath=None, locale=None, image=None, type=None, cluster=None, qsubuser=None, vpc_cidr_block=None, version=None, ssl=None, god=None):
-    if not region and not osspath and not locale and not image and not type and not cluster and not qsubuser and\
-        not vpc_cidr_block and not version and not ssl and not god:
+def all(*args, **kwargs):
+    handlFunc = {
+        "region":  update_region,
+        "osspath": update_osspath,
+        "locale":  update_locale,
+        "image":   update_image,
+        "type":    update_type,
+        "cluster": update_cluster,
+        "version": update_version,
+        "ssl":     update_ssl,
+        "qsubuser": update_qsubuser,
+        "vpc_cidr_block":update_vpc_cidr_block,
+        "god":      update_god,
+        "networktype": update_localhost_network_type,
+    }
+
+    if not kwargs:
         show_config()
     else:
-        if region:
-            update_region(region)
-        if osspath:
-            update_osspath(osspath)
-        if locale:
-            update_locale(locale)
-        if image:
-            update_image(image)
-        if type:
-            update_type(type)
-        if cluster:
-            update_cluster(cluster)
-        if version:
-            update_version(version)
-        if ssl:
-            update_ssl(ssl)
-        if qsubuser:
-            update_qsubuser(qsubuser)
-        if vpc_cidr_block:
-            update_vpc_cidr_block(vpc_cidr_block)
-            
-        if god:
-            update_god(god)
+        for k, v in kwargs.items():
+            if handlFunc.has_key(k):
+                handlFunc[k](v)
         print(green('done'))
 
 def update_region(region):
     m = config.getConfigs(config.COMMON)
     m['region'] = region
 
+    util.check_intranet_region(opt = m)
     try:
         client.check_client(m)
         config.setConfigs(config.COMMON, m)
@@ -194,15 +189,24 @@ def update_god(god):
     else:
         config.removeConfig(config.COMMON, 'god')
 
+def update_localhost_network_type(networktype):
+    if "VPC" != networktype and "Public" != networktype:
+        raise Exception('Invalid networktype %s, the value of networktype must be "VPC" or "Public"' % networktype)
+    
+    if "VPC" == networktype:
+        util.check_intranet_region(networks = networktype)
+
+    m = config.getConfigs(config.COMMON)
+    m['localhostnetworktype'] = networktype
+    config.setConfigs(config.COMMON, m)
+
 
 def show_config():
     try:
-        arr = ['region','accesskeyid','accesskeysecret','version','osspath','locale', 'defaultimage','defaulttype','defaultcluster','ssl','god',
-               'oss_region','oss_id','oss_key','qsubuser','vpc_cidr_block']
-        opt = config.getConfigs(config.COMMON, arr)
+        opt = config.getConfigs(config.COMMON, config.ALL)
         if not opt:
             raise Exception('error')
-        for k in arr:
+        for k in config.ALL:
             if opt.get(k):
                 v = hide_key(opt[k]) if k=='accesskeysecret' else opt[k]
                 print('%s: %s' %(bold(k), green(v)))
