@@ -28,8 +28,8 @@ def getJSON():
                 "god": "use god mode, scope:[true|false]",
                 'ssl': 'requesting with https, scope:[true|false]',
                 'qsubuser': 'set user for qsub, if unspecified, default:root',
-                'vpc_cidr_block': '''specify CIDR IP block for VPC, default: 192.168.0.0/16, if it is set to false, 
-                                    then use the classic network'''
+                'vpc_cidr_block': '''specify CIDR IP block for VPC, default: 192.168.0.0/16, if it is set to false, then use the classic network''',
+                'networktype': '''set network env of the localhost, the value must be "VPC" or "Public"; if it is set "VPC", then the Access to batchcompute or oss passes through aliyun intranet.'''
             }
         },
         'info': {
@@ -154,7 +154,13 @@ def getJSON():
                                              and file is also supported: oss://path/to/mount/a.txt:/home/admin/dir/a.txt.""",
                 'nas_access_group': 'NAS access groups, multiple items should be separated by comma',
                 'nas_file_system': 'NAS file system, multiple items should be separated by comma',
-                'no_cache_support': 'optional, cancel the cache for ossmounter',
+                'locale': 'optional, mount nas or oss paths to local file system with locale, default: UTF-8',
+                'lock': 'optional, mount nas or oss paths to local file system with lock or not, default: false',
+                'no_cache_support': 'optional, cancel the cache for ossmounter, default: false',
+                'cache_block_size': 'optional, cache block size property when using ossmounter, unit bytes, default: 1024 * 256',
+                'cache_total_size': 'optional, cache total size property when using ossmounter, unit bytes, default: 1024 * 1024 * 512',
+                'nas_meta_cache': 'optional, open meta cache when using ossmounter, default: false',
+                'refresh_time_out': 'optional, meta data refresh period in meta cache when using ossmounter, unit second, default 0',
                 'vpc_cidr_block': 'CIDR, such as: 192.168.0.0/16',
                 'vpc_id': 'set VPC id',
                 'show_json': 'optional, just output cluster json, won\'t create a cluster, default: false',
