@@ -8,8 +8,15 @@ import platform
 set_log_level("ERROR")
 
 def _get_endpoint(region):
-    domain = 'batchcompute.%s.aliyuncs.com' % region
-    Client.register_region(region, domain)
+    opt = getConfigs(COMMON, ['localhostnetworktype'])
+
+    if "VPC" == opt.get("localhostnetworktype"):
+        domain = 'batchcompute-vpc.%s.aliyuncs.com' % region
+        region_vpc = region + "_VPC"
+        Client.register_region(region_vpc, domain)
+    else:
+        domain = 'batchcompute.%s.aliyuncs.com' % region
+        Client.register_region(region, domain)
     return domain
 
 
@@ -355,4 +362,13 @@ def __items2list(items):
         for k in item.keys():
             m[k] = item.get(k)
         t.append(m)
-    return t
\ No newline at end of file
+    return t
+
+def describeInstances(opt):
+    client = _get_client(opt)
+    ret = []
+    rsp = client.get_available_resource()
+    ret.extend(rsp.AvailableClusterInstanceType)
+    ret.extend(rsp.AvailableSpotInstanceType)
+
+    return ret
\ No newline at end of file
