@@ -23,16 +23,21 @@ def __get_cfg():
     }
 
 def get_endpoint(region):
-    return 'http://oss-%s.aliyuncs.com' % region
+    opt = config.getConfigs(config.COMMON, ['localhostnetworktype'])
+
+    if "VPC" == opt.get("localhostnetworktype"):
+        return 'http://oss-%s-internal.aliyuncs.com' % region
+    else:
+        return "http://oss-%s.aliyuncs.com" % region
 
 
 def check_client(cfg=None):
 
     cfg = cfg or __get_cfg()
-
     services = _get_service( cfg.get('oss_region') or cfg.get('region'),
                                   cfg.get('oss_id') or cfg.get('accesskeyid'),
-                                  cfg.get('oss_key') or cfg.get('accesskeysecret'))
+                                  cfg.get('oss_key') or cfg.get('accesskeysecret'),
+                             connect_timeout=3)
 
     try:
         services.list_buckets()
@@ -192,24 +197,24 @@ def _list(bucket_tool, key, marker='', delimiter=""):
 
     return (obj_arr, pre_arr)
 
-def get_bucket_tool(bucket, region=None):
+def get_bucket_tool(bucket, region=None, connect_timeout=None):
     cfg = __get_cfg()
 
     return _get_bucket_tool(region or cfg['region'],
                              cfg['accesskeyid'],
                              cfg['accesskeysecret'],
-                            bucket)
+                            bucket, connect_timeout=connect_timeout)
 
-def _get_bucket_tool(region, id, key, bucket):
+def _get_bucket_tool(region, id, key, bucket, connect_timeout=None):
     auth = oss2.Auth(id,key)
     endpoint = get_endpoint(region)
-    bucket_tool = oss2.Bucket(auth, endpoint, bucket)
+    bucket_tool = oss2.Bucket(auth, endpoint, bucket, connect_timeout=connect_timeout)
     return bucket_tool
 
-def _get_service(region, id, key):
+def _get_service(region, id, key, connect_timeout=None):
     auth = oss2.Auth(id,key)
     endpoint = get_endpoint(region)
-    service = oss2.Service(auth, endpoint)
+    service = oss2.Service(auth, endpoint, connect_timeout=connect_timeout)
     return service
 
 def parse_oss_path(oss_path):
