@@ -6,6 +6,8 @@ from ..util import client,result_cache, config,oss_client
 from terminal import yellow,blue
 from ..const import CMD
 import re
+import urllib2
+import time
 MOUNTS_PROTOCOLS = ['smb://','lustre://','nasplus://', 'nas://','oss://']
 
 FALSE_ARR = ['', 'null', 'None', 'false', 'False','0']
@@ -342,4 +344,32 @@ def check_default_vpc_cidr_block():
         m['vpc_cidr_block'] = "192.168.0.0/16"
         print(yellow('\n  [WARN]: default vpc_cidr_block: %s' % m['vpc_cidr_block']))
         config.setConfigs(config.COMMON, m)
-    
\ No newline at end of file
+
+def check_intranet_region(opt = None, networks = None):
+    m = config.getConfigs(config.COMMON)
+    region = opt.get("region") if opt else m.get('region')
+    
+    # localhostnetworktype is default value
+    if m.get('localhostnetworktype') != "VPC" and networks != "VPC":
+        return
+    
+    tmp = None
+    index = 0
+    while index < 3:
+        try:
+            f = urllib2.urlopen('http://100.100.100.200/latest/meta-data/region-id', timeout=1)
+            if f.getcode() < 300:
+                tmp = f.read()
+                break
+        except Exception as e:
+            time.sleep(0.2)
+        index += 1
+    
+    if tmp == None:
+        raise Exception("Can't access aliyun intranet.")
+    
+    if not region:
+        return
+    if region != tmp:
+        raise Exception("The region(%s) was set must be same with the region(%s) of the localhost, "
+                        "or you can't access bathcompute service through aliyun intranet." % (region, tmp))
